@@ -1,22 +1,18 @@
 #
-# $Id: file.pm,v 1.16.2.1 1998/10/12 11:20:46 aas Exp $
+# $Id: file.pm,v 1.15 1996/09/13 15:47:00 aas Exp $
 
 package LWP::Protocol::file;
 
 require LWP::Protocol;
-@ISA = qw(LWP::Protocol);
-
-use strict;
-
 require LWP::MediaTypes;
 require HTTP::Request;
 require HTTP::Response;
 require HTTP::Status;
 require HTTP::Date;
 
-require URI::Escape;
-require HTML::Entities;
+use Carp;
 
+@ISA = qw(LWP::Protocol);
 
 
 sub request
@@ -35,7 +31,8 @@ sub request
     }
 
     # check method
-    my $method = $request->method;
+    $method = $request->method;
+
     unless ($method eq 'GET' || $method eq 'HEAD') {
 	return new HTTP::Response &HTTP::Status::RC_BAD_REQUEST,
 				  'Library does not allow method ' .
@@ -51,8 +48,14 @@ sub request
 				  "LWP::file::request called for '$scheme'";
     }
 
+    my $host = $url->host;
+    if ($host and $host !~ /^localhost$/i) {
+	return new HTTP::Response &HTTP::Status::RC_BAD_REQUEST_CLIENT,
+				  'Only file://localhost/ allowed';
+    }
+
     # URL OK, look at file
-    my $path  = $url->file;
+    my $path  = $url->local_path;
 
     # test file exists and is readable
     unless (-e $path) {
@@ -82,7 +85,7 @@ sub request
     }
 
     # Ok, should be an OK response by now...
-    my $response = new HTTP::Response &HTTP::Status::RC_OK;
+    $response = new HTTP::Response &HTTP::Status::RC_OK;
 
     # fill in response headers
     $response->header('Last-Modified', HTTP::Date::time2str($mtime));
@@ -98,9 +101,7 @@ sub request
 	# Make directory listing
 	for (@files) {
 	    $_ .= "/" if -d "$path/$_";
-	    my $furl = URI::Escape::uri_escape($_);
-	    my $desc = HTML::Entities::encode($_);
-	    $_ = qq{<LI><A HREF="$furl">$desc</A>};
+	    $_ = qq{<LI> <a href="$_">$_</a>};
 	}
 	# Ensure that the base URL is "/" terminated
 	my $base = $url->clone;
@@ -118,21 +119,21 @@ sub request
 
 	$response->header('Content-Type',   'text/html');
 	$response->header('Content-Length', length $html);
-	$html = "" if $method eq "HEAD";
 
 	return $self->collect_once($arg, $response, $html);
 
-    }
+    } else {            # path is a regular file
+	my($type, @enc) = LWP::MediaTypes::guess_media_type($path);
+	$response->header('Content-Type',   $type) if $type;
+	$response->header('Content-Length', $filesize);
+	for (@enc) {
+	    $response->push_header('Content-Encoding', $_);
+	}
 
-    # path is a regular file
-    $response->header('Content-Length', $filesize);
-    LWP::MediaTypes::guess_media_type($path, $response);
-
-    # read the file
-    if ($method ne "HEAD") {
+	# read the file
 	open(F, $path) or return new
-	    HTTP::Response(&HTTP::Status::RC_INTERNAL_SERVER_ERROR,
-			   "Cannot read file '$path': $!");
+	   HTTP::Response(&HTTP::Status::RC_INTERNAL_SERVER_ERROR,
+			  "Cannot read file '$path': $!");
 	$response =  $self->collect($arg, $response, sub {
 	    my $content = "";
 	    my $bytes = sysread(F, $content, $size);
